==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/hu_HU.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Múltbéli lejárati idő.",
"Couldn't send mail to following users: %s " => "Nem sikerült e-mailt küldeni a következő felhasználóknak: %s",
"Turned on maintenance mode" => "A karbantartási mód bekapcsolva",
"Turned off maintenance mode" => "A karbantartási mód kikapcsolva",
"Updated database" => "Az adatbázis frissítése megtörtént",
"Checked database schema update" => "Az adatbázis séma frissítését ellenőrztük",
"Disabled incompatible apps: %s" => "Letiltásra került inkompatibilis alkalmazások: %s",
"No image or file provided" => "Nincs kép vagy file megadva",
"Unknown filetype" => "Ismeretlen fájltípus",
"Invalid image" => "Hibás kép",
"No temporary profile picture available, try again" => "Az átmeneti profilkép nem elérhető, próbálja újra",
"No crop data provided" => "Vágáshoz nincs adat megadva",
"Sunday" => "vasárnap",
"Monday" => "hétfő",
"Tuesday" => "kedd",
"Wednesday" => "szerda",
"Thursday" => "csütörtök",
"Friday" => "péntek",
"Saturday" => "szombat",
"January" => "január",
"February" => "február",
"March" => "március",
"April" => "április",
"May" => "május",
"June" => "június",
"July" => "július",
"August" => "augusztus",
"September" => "szeptember",
"October" => "október",
"November" => "november",
"December" => "december",
"Settings" => "Beállítások",
"File" => "Fájl",
"Folder" => "Mappa",
"Image" => "Kép",
"Audio" => "Hang",
"Saving..." => "Mentés...",
"seconds ago" => "pár másodperce",
"_%n minute ago_::_%n minutes ago_" => array("%n perccel ezelőtt","%n perccel ezelőtt"),
"_%n hour ago_::_%n hours ago_" => array("%n órával ezelőtt","%n órával ezelőtt"),
"today" => "ma",
"yesterday" => "tegnap",
"_%n day ago_::_%n days ago_" => array("%n nappal ezelőtt","%n nappal ezelőtt"),
"last month" => "múlt hónapban",
"_%n month ago_::_%n months ago_" => array("%n hónappal ezelőtt","%n hónappal ezelőtt"),
"last year" => "tavaly",
"years ago" => "több éve",
"Reset password" => "Jelszó-visszaállítás",
"Yes" => "Igen",
"No" => "Nem",
"Choose" => "Válasszon",
"Error loading file picker template: {error}" => "Nem sikerült betölteni a fájlkiválasztó sablont: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Nem sikerült betölteni az üzenet sablont: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fájl ütközik","{count} fájl ütközik"),
"One file conflict" => "Egy file ütközik",
"New Files" => "Új fájlok",
"Already existing files" => "A fájlok már léteznek",
"Which files do you want to keep?" => "Melyik fájlokat akarja megtartani?",
"If you select both versions, the copied file will have a number added to its name." => "Ha mindkét verziót kiválasztja, a másolt fájlok neve sorszámozva lesz.",
"Cancel" => "Mégsem",
"Continue" => "Folytatás",
"(all selected)" => "(az összes ki lett választva)",
"({count} selected)" => "({count} lett kiválasztva)",
"Error loading file exists template" => "Hiba a létezőfájl-sablon betöltésekor",
"Very weak password" => "Nagyon gyenge jelszó",
"Weak password" => "Gyenge jelszó",
"So-so password" => "Nem túl jó jelszó",
"Good password" => "Jó jelszó",
"Strong password" => "Erős jelszó",
"Shared" => "Megosztott",
"Shared by {owner}" => "Megosztotta: {owner}",
"Shared with {recipients}" => "Megosztva ővelük: {recipients}",
"Share" => "Megosztás",
"Error" => "Hiba",
"Error while sharing" => "Nem sikerült létrehozni a megosztást",
"Error while unsharing" => "Nem sikerült visszavonni a megosztást",
"Error while changing permissions" => "Nem sikerült módosítani a jogosultságokat",
"Shared with you and the group {group} by {owner}" => "Megosztotta Önnel és a(z) {group} csoporttal: {owner}",
"Shared with you by {owner}" => "Megosztotta Önnel: {owner}",
"Share with user or group …" => "Megosztani egy felhasználóval vagy csoporttal ...",
"Share link" => "Megosztás hivatkozással",
"The public link will expire no later than {days} days after it is created" => "A nyilvános link érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
"By default the public link will expire after {days} days" => "A nyilvános link érvényessége alapértelmezetten {days} nap múlva jár le",
"Password protect" => "Jelszóval is védem",
"Choose a password for the public link" => "Válasszon egy jelszót a nyilvános linkhez",
"Allow Public Upload" => "Feltöltést is engedélyezek",
"Email link to person" => "Email címre küldjük el",
"Send" => "Küldjük el",
"Set expiration date" => "Legyen lejárati idő",
"Expiration date" => "A lejárati idő",
"Share via email:" => "Megosztás emaillel:",
"No people found" => "Nincs találat",
"group" => "csoport",
"Resharing is not allowed" => "Ezt az állományt csak a tulajdonosa oszthatja meg másokkal",
"Shared in {item} with {user}" => "Megosztva {item}-ben {user}-rel",
"Unshare" => "A megosztás visszavonása",
"notify by email" => "email értesítés",
"can share" => "megosztható",
"can edit" => "módosíthat",
"access control" => "jogosultság",
"create" => "létrehoz",
"update" => "szerkeszt",
"delete" => "töröl",
"Password protected" => "Jelszóval van védve",
"Error unsetting expiration date" => "Nem sikerült a lejárati időt törölni",
"Error setting expiration date" => "Nem sikerült a lejárati időt beállítani",
"Sending ..." => "Küldés ...",
"Email sent" => "Az emailt elküldtük",
"Warning" => "Figyelmeztetés",
"The object type is not specified." => "Az objektum típusa nincs megadva.",
"Enter new" => "Új beírása",
"Delete" => "Törlés",
"Add" => "Hozzáadás",
"Edit tags" => "Címkék szerkesztése",
"Error loading dialog template: {error}" => "Hiba a párbeszédpanel-sablon betöltésekor: {error}",
"No tags selected for deletion." => "Nincs törlésre kijelölt címke.",
"Updating {productName} to version {version}, this may take a while." => " {productName} frissítése zajlik erre a verzióra: {version}. Ez eltarthat egy darabig.",
"Please reload the page." => "Kérjük frissítse az oldalt!",
"The update was unsuccessful." => "A frissítés nem sikerült.",
"The update was successful. Redirecting you to ownCloud now." => "A frissítés sikeres volt. Visszairányítjuk az ownCloud szolgáltatáshoz.",
"%s password reset" => "%s jelszó visszaállítás",
"Use the following link to reset your password: {link}" => "Használja ezt a linket a jelszó ismételt beállításához: {link}",
"You will receive a link to reset your password via Email." => "Egy emailben fog értesítést kapni a jelszóbeállítás módjáról.",
"Username" => "Felhasználónév",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Az Ön állományai titkosítva vannak. Ha nem engedélyezte korábban az adatok visszanyeréséhez szükséges kulcs használatát, akkor a jelszó megváltoztatását követően nem fog hozzáférni az adataihoz. Ha nem biztos abban, hogy mit kellene tennie, akkor kérdezze meg a rendszergazdát, mielőtt továbbmenne. Biztos, hogy folytatni kívánja?",
"Yes, I really want to reset my password now" => "Igen, tényleg meg akarom változtatni a jelszavam",
"Reset" => "Visszaállítás",
"New password" => "Az új jelszó",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Felhasználás csak saját felelősségre!",
"For the best results, please consider using a GNU/Linux server instead." => "A legjobb eredmény érdekében érdemes GNU/Linux-alapú kiszolgálót használni.",
"Personal" => "Személyes",
"Users" => "Felhasználók",
"Apps" => "Alkalmazások",
"Admin" => "Adminsztráció",
"Help" => "Súgó",
"Error loading tags" => "Hiba a címkék betöltésekor",
"Tag already exists" => "A címke már létezik",
"Error deleting tag(s)" => "Hiba a címkék törlésekor",
"Error tagging" => "Hiba a címkézéskor",
"Error untagging" => "Hiba a címkék eltávolításakor",
"Error favoriting" => "Hiba a kedvencekhez adáskor",
"Error unfavoriting" => "Hiba a kedvencekből törléskor",
"Access forbidden" => "A hozzáférés nem engedélyezett",
"Cloud not found" => "A felhő nem található",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Üdv!\\n\n\\n\nÉrtesítjük, hogy %s megosztotta Önnel a következőt: %s.\\n\nItt lehet megnézni: %s\\n\n\\n",
"The share will expire on %s." => "A megosztás lejár ekkor %s",
"Cheers!" => "Üdv.",
"Security Warning" => "Biztonsági figyelmeztetés",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Az Ön PHP verziója sebezhető a NULL bájtos támadással szemben (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Kérjük frissítse a telepített PHP csomagjait, hogy biztonságos legyen az %s szolgáltatása.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Nem érhető el megfelelő véletlenszám-generátor, telepíteni kellene a PHP OpenSSL kiegészítését.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Megfelelő véletlenszám-generátor hiányában egy támadó szándékú idegen képes lehet megjósolni a jelszóvisszaállító tokent, és Ön helyett belépni.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Az adatkönyvtár és a benne levő állományok valószínűleg közvetlenül is elérhetők az internetről, mert a .htaccess állomány nem érvényesül.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "A kiszolgáló megfelelő beállításához kérjük olvassa el a <a href=\"%sl\" target=\"_blank\">dokumentációt</a>.",
"Create an <strong>admin account</strong>" => "<strong>Rendszergazdai belépés</strong> létrehozása",
"Password" => "Jelszó",
"Storage & database" => "Tárolás és adatbázis",
"Data folder" => "Adatkönyvtár",
"Configure the database" => "Adatbázis konfigurálása",
"Only %s is available." => "Csak %s érhető el.",
"Database user" => "Adatbázis felhasználónév",
"Database password" => "Adatbázis jelszó",
"Database name" => "Az adatbázis neve",
"Database tablespace" => "Az adatbázis táblázattér (tablespace)",
"Database host" => "Adatbázis szerver",
"SQLite will be used as database. For larger installations we recommend to change this." => "Adatbázisként az SQLite-ot fogjuk használni. Nagyobb telepítések esetén javasoljuk, hogy változtassa meg ezt a beállítást.",
"Finish setup" => "A beállítások befejezése",
"Finishing …" => "Befejezés ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Az alkalmazás megfelelő működéséhez szükség van JavaScriptre. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Engedélyezze a JavaScriptet</a> és frissítse az oldalt!",
"%s is available. Get more information on how to update." => "%s rendelkezésre áll. További információ a frissítéshez.",
"Log out" => "Kilépés",
"Automatic logon rejected!" => "Az automatikus bejelentkezés sikertelen!",
"If you did not change your password recently, your account may be compromised!" => "Ha mostanában nem módosította a jelszavát, akkor lehetséges, hogy idegenek jutottak be a rendszerbe az Ön nevében!",
"Please change your password to secure your account again." => "A biztonsága érdekében változtassa meg a jelszavát!",
"Server side authentication failed!" => "A szerveroldali hitelesítés sikertelen!",
"Please contact your administrator." => "Kérjük, lépjen kapcsolatba a rendszergazdával.",
"remember" => "emlékezzen",
"Log in" => "Bejelentkezés",
"Alternative Logins" => "Alternatív bejelentkezés",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Üdvözöljük!<br><br>\n\nÉrtesítjük, hogy %s megosztotta Önnel ezt az állományt: <strong>%s</strong><br>\n<a href=\"%s\">Itt lehet megnézni!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Ez az ownCloud szolgáltatás jelenleg egyfelhasználós üzemmódban működik.",
"This means only administrators can use the instance." => "Ez azt jelenti, hogy csak az adminisztrátor használhatja ezt a példányt",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Ha ez az üzenet ismételten vagy indokolatlanul megjelenik, akkor keresse a rendszergazda segítségét!",
"Thank you for your patience." => "Köszönjük a türelmét.",
"%s will be updated to version %s." => "%s frissítődni fog erre a verzióra: %s.",
"The following apps will be disabled:" => "A következő alkalmazások lesznek letiltva:",
"The theme %s has been disabled." => "Ez a smink: %s letiltásra került.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Kérjük gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatamappa tartalmát, mielőtt folytatja.",
"Start update" => "A frissítés megkezdése",
"This ownCloud instance is currently being updated, which may take a while." => "Az ownCloud frissítés elkezdődött, ez eltarthat egy ideig.",
"Please reload this page after a short time to continue using ownCloud." => "Frissitse az oldalt egy kis idő múlva, ha folytatni kívánja az ownCloud használatát."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/hu_HU.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Múltbéli lejárati idő.",
"Couldn't send mail to following users: %s " => "Nem sikerült e-mailt küldeni a következő felhasználóknak: %s",
"Turned on maintenance mode" => "A karbantartási mód bekapcsolva",
"Turned off maintenance mode" => "A karbantartási mód kikapcsolva",
"Updated database" => "Az adatbázis frissítése megtörtént",
"Checked database schema update" => "Az adatbázis séma frissítését ellenőrztük",
"Disabled incompatible apps: %s" => "Letiltásra került inkompatibilis alkalmazások: %s",
"No image or file provided" => "Nincs kép vagy file megadva",
"Unknown filetype" => "Ismeretlen fájltípus",
"Invalid image" => "Hibás kép",
"No temporary profile picture available, try again" => "Az átmeneti profilkép nem elérhető, próbálja újra",
"No crop data provided" => "Vágáshoz nincs adat megadva",
"Sunday" => "vasárnap",
"Monday" => "hétfő",
"Tuesday" => "kedd",
"Wednesday" => "szerda",
"Thursday" => "csütörtök",
"Friday" => "péntek",
"Saturday" => "szombat",
"January" => "január",
"February" => "február",
"March" => "március",
"April" => "április",
"May" => "május",
"June" => "június",
"July" => "július",
"August" => "augusztus",
"September" => "szeptember",
"October" => "október",
"November" => "november",
"December" => "december",
"Settings" => "Beállítások",
"File" => "Fájl",
"Folder" => "Mappa",
"Image" => "Kép",
"Audio" => "Hang",
"Saving..." => "Mentés...",
"seconds ago" => "pár másodperce",
"_%n minute ago_::_%n minutes ago_" => array("%n perccel ezelőtt","%n perccel ezelőtt"),
"_%n hour ago_::_%n hours ago_" => array("%n órával ezelőtt","%n órával ezelőtt"),
"today" => "ma",
"yesterday" => "tegnap",
"_%n day ago_::_%n days ago_" => array("%n nappal ezelőtt","%n nappal ezelőtt"),
"last month" => "múlt hónapban",
"_%n month ago_::_%n months ago_" => array("%n hónappal ezelőtt","%n hónappal ezelőtt"),
"last year" => "tavaly",
"years ago" => "több éve",
"Reset password" => "Jelszó-visszaállítás",
"Yes" => "Igen",
"No" => "Nem",
"Choose" => "Válasszon",
"Error loading file picker template: {error}" => "Nem sikerült betölteni a fájlkiválasztó sablont: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Nem sikerült betölteni az üzenet sablont: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fájl ütközik","{count} fájl ütközik"),
"One file conflict" => "Egy file ütközik",
"New Files" => "Új fájlok",
"Already existing files" => "A fájlok már léteznek",
"Which files do you want to keep?" => "Melyik fájlokat akarja megtartani?",
"If you select both versions, the copied file will have a number added to its name." => "Ha mindkét verziót kiválasztja, a másolt fájlok neve sorszámozva lesz.",
"Cancel" => "Mégsem",
"Continue" => "Folytatás",
"(all selected)" => "(az összes ki lett választva)",
"({count} selected)" => "({count} lett kiválasztva)",
"Error loading file exists template" => "Hiba a létezőfájl-sablon betöltésekor",
"Very weak password" => "Nagyon gyenge jelszó",
"Weak password" => "Gyenge jelszó",
"So-so password" => "Nem túl jó jelszó",
"Good password" => "Jó jelszó",
"Strong password" => "Erős jelszó",
"Shared" => "Megosztott",
"Shared by {owner}" => "Megosztotta: {owner}",
"Shared with {recipients}" => "Megosztva ővelük: {recipients}",
"Share" => "Megosztás",
"Error" => "Hiba",
"Error while sharing" => "Nem sikerült létrehozni a megosztást",
"Error while unsharing" => "Nem sikerült visszavonni a megosztást",
"Error while changing permissions" => "Nem sikerült módosítani a jogosultságokat",
"Shared with you and the group {group} by {owner}" => "Megosztotta Önnel és a(z) {group} csoporttal: {owner}",
"Shared with you by {owner}" => "Megosztotta Önnel: {owner}",
"Share with user or group …" => "Megosztani egy felhasználóval vagy csoporttal ...",
"Share link" => "Megosztás hivatkozással",
"The public link will expire no later than {days} days after it is created" => "A nyilvános link érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
"By default the public link will expire after {days} days" => "A nyilvános link érvényessége alapértelmezetten {days} nap múlva jár le",
"Password protect" => "Jelszóval is védem",
"Choose a password for the public link" => "Válasszon egy jelszót a nyilvános linkhez",
"Allow Public Upload" => "Feltöltést is engedélyezek",
"Email link to person" => "Email címre küldjük el",
"Send" => "Küldjük el",
"Set expiration date" => "Legyen lejárati idő",
"Expiration date" => "A lejárati idő",
"Share via email:" => "Megosztás emaillel:",
"No people found" => "Nincs találat",
"group" => "csoport",
"Resharing is not allowed" => "Ezt az állományt csak a tulajdonosa oszthatja meg másokkal",
"Shared in {item} with {user}" => "Megosztva {item}-ben {user}-rel",
"Unshare" => "A megosztás visszavonása",
"notify by email" => "email értesítés",
"can share" => "megosztható",
"can edit" => "módosíthat",
"access control" => "jogosultság",
"create" => "létrehoz",
"update" => "szerkeszt",
"delete" => "töröl",
"Password protected" => "Jelszóval van védve",
"Error unsetting expiration date" => "Nem sikerült a lejárati időt törölni",
"Error setting expiration date" => "Nem sikerült a lejárati időt beállítani",
"Sending ..." => "Küldés ...",
"Email sent" => "Az emailt elküldtük",
"Warning" => "Figyelmeztetés",
"The object type is not specified." => "Az objektum típusa nincs megadva.",
"Enter new" => "Új beírása",
"Delete" => "Törlés",
"Add" => "Hozzáadás",
"Edit tags" => "Címkék szerkesztése",
"Error loading dialog template: {error}" => "Hiba a párbeszédpanel-sablon betöltésekor: {error}",
"No tags selected for deletion." => "Nincs törlésre kijelölt címke.",
"Updating {productName} to version {version}, this may take a while." => " {productName} frissítése zajlik erre a verzióra: {version}. Ez eltarthat egy darabig.",
"Please reload the page." => "Kérjük frissítse az oldalt!",
"The update was unsuccessful." => "A frissítés nem sikerült.",
"The update was successful. Redirecting you to ownCloud now." => "A frissítés sikeres volt. Visszairányítjuk az ownCloud szolgáltatáshoz.",
"%s password reset" => "%s jelszó visszaállítás",
"Use the following link to reset your password: {link}" => "Használja ezt a linket a jelszó ismételt beállításához: {link}",
"You will receive a link to reset your password via Email." => "Egy emailben fog értesítést kapni a jelszóbeállítás módjáról.",
"Username" => "Felhasználónév",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Az Ön állományai titkosítva vannak. Ha nem engedélyezte korábban az adatok visszanyeréséhez szükséges kulcs használatát, akkor a jelszó megváltoztatását követően nem fog hozzáférni az adataihoz. Ha nem biztos abban, hogy mit kellene tennie, akkor kérdezze meg a rendszergazdát, mielőtt továbbmenne. Biztos, hogy folytatni kívánja?",
"Yes, I really want to reset my password now" => "Igen, tényleg meg akarom változtatni a jelszavam",
"Reset" => "Visszaállítás",
"New password" => "Az új jelszó",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Felhasználás csak saját felelősségre!",
"For the best results, please consider using a GNU/Linux server instead." => "A legjobb eredmény érdekében érdemes GNU/Linux-alapú kiszolgálót használni.",
"Personal" => "Személyes",
"Users" => "Felhasználók",
"Apps" => "Alkalmazások",
"Admin" => "Adminsztráció",
"Help" => "Súgó",
"Error loading tags" => "Hiba a címkék betöltésekor",
"Tag already exists" => "A címke már létezik",
"Error deleting tag(s)" => "Hiba a címkék törlésekor",
"Error tagging" => "Hiba a címkézéskor",
"Error untagging" => "Hiba a címkék eltávolításakor",
"Error favoriting" => "Hiba a kedvencekhez adáskor",
"Error unfavoriting" => "Hiba a kedvencekből törléskor",
"Access forbidden" => "A hozzáférés nem engedélyezett",
"Cloud not found" => "A felhő nem található",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Üdv!\\n\n\\n\nÉrtesítjük, hogy %s megosztotta Önnel a következőt: %s.\\n\nItt lehet megnézni: %s\\n\n\\n",
"The share will expire on %s." => "A megosztás lejár ekkor %s",
"Cheers!" => "Üdv.",
"Security Warning" => "Biztonsági figyelmeztetés",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Az Ön PHP verziója sebezhető a NULL bájtos támadással szemben (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Kérjük frissítse a telepített PHP csomagjait, hogy biztonságos legyen az %s szolgáltatása.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Nem érhető el megfelelő véletlenszám-generátor, telepíteni kellene a PHP OpenSSL kiegészítését.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Megfelelő véletlenszám-generátor hiányában egy támadó szándékú idegen képes lehet megjósolni a jelszóvisszaállító tokent, és Ön helyett belépni.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Az adatkönyvtár és a benne levő állományok valószínűleg közvetlenül is elérhetők az internetről, mert a .htaccess állomány nem érvényesül.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "A kiszolgáló megfelelő beállításához kérjük olvassa el a <a href=\"%sl\" target=\"_blank\">dokumentációt</a>.",
"Create an <strong>admin account</strong>" => "<strong>Rendszergazdai belépés</strong> létrehozása",
"Password" => "Jelszó",
"Storage & database" => "Tárolás és adatbázis",
"Data folder" => "Adatkönyvtár",
"Configure the database" => "Adatbázis konfigurálása",
"Only %s is available." => "Csak %s érhető el.",
"Database user" => "Adatbázis felhasználónév",
"Database password" => "Adatbázis jelszó",
"Database name" => "Az adatbázis neve",
"Database tablespace" => "Az adatbázis táblázattér (tablespace)",
"Database host" => "Adatbázis szerver",
"SQLite will be used as database. For larger installations we recommend to change this." => "Adatbázisként az SQLite-ot fogjuk használni. Nagyobb telepítések esetén javasoljuk, hogy változtassa meg ezt a beállítást.",
"Finish setup" => "A beállítások befejezése",
"Finishing …" => "Befejezés ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Az alkalmazás megfelelő működéséhez szükség van JavaScriptre. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Engedélyezze a JavaScriptet</a> és frissítse az oldalt!",
"%s is available. Get more information on how to update." => "%s rendelkezésre áll. További információ a frissítéshez.",
"Log out" => "Kilépés",
"Automatic logon rejected!" => "Az automatikus bejelentkezés sikertelen!",
"If you did not change your password recently, your account may be compromised!" => "Ha mostanában nem módosította a jelszavát, akkor lehetséges, hogy idegenek jutottak be a rendszerbe az Ön nevében!",
"Please change your password to secure your account again." => "A biztonsága érdekében változtassa meg a jelszavát!",
"Server side authentication failed!" => "A szerveroldali hitelesítés sikertelen!",
"Please contact your administrator." => "Kérjük, lépjen kapcsolatba a rendszergazdával.",
"remember" => "emlékezzen",
"Log in" => "Bejelentkezés",
"Alternative Logins" => "Alternatív bejelentkezés",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Üdvözöljük!<br><br>\n\nÉrtesítjük, hogy %s megosztotta Önnel ezt az állományt: <strong>%s</strong><br>\n<a href=\"%s\">Itt lehet megnézni!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Ez az ownCloud szolgáltatás jelenleg egyfelhasználós üzemmódban működik.",
"This means only administrators can use the instance." => "Ez azt jelenti, hogy csak az adminisztrátor használhatja ezt a példányt",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Ha ez az üzenet ismételten vagy indokolatlanul megjelenik, akkor keresse a rendszergazda segítségét!",
"Thank you for your patience." => "Köszönjük a türelmét.",
"%s will be updated to version %s." => "%s frissítődni fog erre a verzióra: %s.",
"The following apps will be disabled:" => "A következő alkalmazások lesznek letiltva:",
"The theme %s has been disabled." => "Ez a smink: %s letiltásra került.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Kérjük gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatamappa tartalmát, mielőtt folytatja.",
"Start update" => "A frissítés megkezdése",
"This ownCloud instance is currently being updated, which may take a while." => "Az ownCloud frissítés elkezdődött, ez eltarthat egy ideig.",
"Please reload this page after a short time to continue using ownCloud." => "Frissitse az oldalt egy kis idő múlva, ha folytatni kívánja az ownCloud használatát.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Nagyobb telepítések esetén úgy kerülhetők el az időtúllépések, ha inkább a következő parancsot adja ki a telepítési alkönyvtárban:"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
